makeLazyLoading <- function(package, lib.loc = NULL, compress = TRUE,
                            keep.source = getOption("keep.source.pkgs")) {
    sQuote <- function(s) paste("'", s, "'", sep = "")
    findpack <- function(package, lib.loc) {
        pkgpath <- .find.package(package, lib.loc, quiet = TRUE)
        if(length(pkgpath) == 0)
            stop(paste("There is no package called", sQuote(package)))
        pkgpath
    }
        
    if (match(package, c("serialize", "gdbm", "shelf"), 0))
        stop(paste("cannot use lazy loading with package", sQuote(package))) 

    pkgpath <- findpack(package, lib.loc)
    lazypath <- findpack("lazyload", lib.loc)

    if (package == "base")
        loaderFile <- file.path(lazypath, "baseloader.R")
    else
        loaderFile <- file.path(lazypath, "packloader.R")
    codeFile <- file.path(pkgpath, "R", package)

    if (file.info(codeFile)["size"] == file.info(loaderFile)["size"])
        warning("package seems to be using lazy loading already")
    else if (package == "base") {
        dbFile <- file.path(pkgpath, "R", "base.gdbm")
        if (! file.exists(dbFile))
            stop("you need to first build the base DB with `makebasedb.R'")
        if (file.info(codeFile)["mtime"] > file.info(dbFile)["mtime"])
            stop("code file newer than base DB; rebuild with `makebasedb.R'")
        file.copy(loaderFile, codeFile, TRUE)
    }
    else {
        rdaFile <- file.path(pkgpath, "R", "all.rda")
        if (file.exists(rdaFile))
            rda2shelf(package, lib.loc)
        else
            code2shelf(package, lib.loc = lib.loc, keep.source = keep.source)
        file.copy(loaderFile, codeFile, TRUE)
    }
}
