\name{lazyload}
\title{Lazy Loading of Packages}
\usage{
code2shelf(package, lib.loc = NULL, 
    keep.source = getOption("keep.source.pkgs"))
makeLazyLoading(package, lib.loc = NULL, compress = TRUE,
    keep.source = getOption("keep.source.pkgs"))
rda2shelf(package, lib.loc = NULL)
}
\alias{code2shelf}
\alias{makeLazyLoading}
\alias{rda2shelf}
\arguments{
  \item{package}{package name string}
  \item{lib.loc}{library trees, as in \code{library}}
  \item{keep.source}{logical; should sources be kept when saving from source}
  \item{compress}{logical; should serializetion compress (ignored for now)}
}
\description{
  Tools for lazy loading of packages from a data base.
}
\details{
  This package provides tools to set up packages for lazy loading from a
  data base.  For packages other than base you can use
  \code{makeLazyLoading(package)} to convert them to use lazy loading from
  a \code{shelf} data base as implemented by the \code{shelf} package.

  For base you need to start R with no packages loaded,  e.g. by setting
  \code{R_PROFILE} to \code{nopack.R}, and then source \code{makebasedb.R};
  these files are provided in the package diractory.  This builds a simpler
  \code{gdbm} data base.  Once the data base has been built, use
  makeLazyLoading("base") to convert base to use lazy loading.

  A simple \code{make} seems sufficient to undo this for base and base
  packages other than \code{methods}.  For \code{methods} (and
  presumably others created with \code{--save}) it appears that you
  need to remove \code{methods/R/methods} and then use \code{make}.
  You may also need more radical action for recommended packages.
}
\examples{
  # set up package "base" for lazy loading (must have no packages loaded)
  \dontrun{
    source(file.path(.find.package("lazyload"),"makebasedb.R"))
    library(lazyload)
    makeLazyLoading("base")
  }

  # set up package "ctest" for lazy loading
  \dontrun{
    library(lazyload)
    makeLazyLoading("ctest")
  }
}
\keyword{internal}
\author{Luke Tierney}
